@@ -1,6 +1,6 @@
+from bai2.helpers import IteratorHelper
 from bai2.parsers import Bai2FileParser
 from bai2.writers import Bai2FileWriter
-from bai2.helpers import IteratorHelper
 
 
 def parse_from_lines(lines, **kwargs):
@@ -10,7 +10,8 @@ def parse_from_lines(lines, **kwargs):
 
 
 def parse_from_string(s, **kwargs):
-    return parse_from_lines(s.splitlines(), **kwargs)
+    lines = filter(None, (line.strip() for line in s.splitlines()))
+    return parse_from_lines(lines, **kwargs)
 
 
 def parse_from_file(f, **kwargs):
