@@ -102,8 +102,11 @@ TypeCodes = [
     TypeCode('084', None, TypeCodeLevel.status, 'Average 2-Day Float MTD'),
     TypeCode('085', None, TypeCodeLevel.status, 'Average 2-Day Float YTD'),
     TypeCode('086', None, TypeCodeLevel.status, 'Transfer Calculation'),
+    TypeCode('087', None, TypeCodeLevel.status, 'MTD Ave Collected'),
+    TypeCode('088', None, TypeCodeLevel.status, 'MTD Ave Neg Collected'),
     TypeCode('100', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total Credits'),
     TypeCode('101', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total Credit Amount MTD'),
+    TypeCode('102', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total Number of Credits'),
     TypeCode('105', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Credits Not Detailed'),
     TypeCode('106', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Deposits Subject to Float'),
     TypeCode('107', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total Adjustment Credits YTD'),
@@ -130,6 +133,8 @@ TypeCodes = [
     TypeCode('150', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total Preauthorized Payment Credits'),
     TypeCode('155', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Preauthorized Draft Credit'),
     TypeCode('156', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Item in PAC Deposit'),
+    TypeCode('158', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Real Time Payment Credit'),
+    TypeCode('159', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total Real Time Payment Credits'),
     TypeCode('160', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total ACH Disbursing Funding Credits'),
     TypeCode('162', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Corporate Trade Payment Settlement'),
     TypeCode('163', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Corporate Trade Payment Credits'),
@@ -311,6 +316,7 @@ TypeCodes = [
     TypeCode('399', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Miscellaneous Credit'),
     TypeCode('400', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Total Debits'),
     TypeCode('401', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Total Debit Amount MTD'),
+    TypeCode('402', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Total Number of Debits'),
     TypeCode('403', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Today’s Total Debits'),
     TypeCode('405', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Total Debit Less Wire Transfers and '
                                                                       'ChargeBacks'),
@@ -334,6 +340,8 @@ TypeCodes = [
     TypeCode('451', TypeCodeTransaction.debit, TypeCodeLevel.detail, 'ACH Debit Received'),
     TypeCode('452', TypeCodeTransaction.debit, TypeCodeLevel.detail, 'Item in ACH Disbursement or Debit'),
     TypeCode('455', TypeCodeTransaction.debit, TypeCodeLevel.detail, 'Preauthorized ACH Debit'),
+    TypeCode('458', TypeCodeTransaction.debit, TypeCodeLevel.detail, 'Real Time Payment Debit'),
+    TypeCode('459', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Total Real Time Payment Debits'),
     TypeCode('462', TypeCodeTransaction.debit, TypeCodeLevel.detail, 'Account Holder Initiated ACH Debit'),
     TypeCode('463', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Corporate Trade Payment Debits'),
     TypeCode('464', TypeCodeTransaction.debit, TypeCodeLevel.detail, 'Corporate Trade Payment Debit'),
@@ -512,7 +520,9 @@ TypeCodes = [
     TypeCode('701', None, TypeCodeLevel.status, 'Principal Loan Balance'),
     TypeCode('703', None, TypeCodeLevel.status, 'Available Commitment Amount'),
     TypeCode('705', None, TypeCodeLevel.status, 'Payment Amount Due'),
+    TypeCode('706', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Loan Participation'),
     TypeCode('707', None, TypeCodeLevel.status, 'Principal Amount Past Due'),
+    TypeCode('708', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Value Dated Funds'),
     TypeCode('709', None, TypeCodeLevel.status, 'Interest Amount Past Due'),
     TypeCode('720', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Total Loan Payment'),
     TypeCode('721', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Amount Applied to Interest'),
@@ -524,7 +534,12 @@ TypeCodes = [
     TypeCode('727', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Amount Applied to Deferred Interest Detail'),
     TypeCode('728', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Amount Applied to Service Charge'),
     TypeCode('760', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Loan Disbursement'),
+    TypeCode('827', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Incoming SEPA Payments'),
+    TypeCode('828', TypeCodeTransaction.debit, TypeCodeLevel.summary, 'Outgoing SEPA Payments'),
+    TypeCode('829', TypeCodeTransaction.credit, TypeCodeLevel.summary, 'Incoming BACS Payment'),
     TypeCode('890', TypeCodeTransaction.misc, TypeCodeLevel.detail, 'Contains Non-monetary Information'),
+    TypeCode('906', None, TypeCodeLevel.detail, 'Today’s Opening 1 Day Float'),
+    TypeCode('907', None, TypeCodeLevel.detail, 'Today’s Opening 2+ Day Float'),
 ]
 TypeCodes = {
     type_code.code: type_code
