@@ -1,19 +1,31 @@
 import datetime
-from unittest import TestCase
 from collections import OrderedDict
+from unittest import TestCase, mock
 
+from bai2.constants import (
+    AsOfDateModifier,
+    FundsType,
+    GroupStatus,
+    TypeCode,
+    TypeCodeLevel,
+    TypeCodes,
+    TypeCodeTransaction,
+)
+from bai2.exceptions import IntegrityException, NotSupportedYetException, ParsingException
 from bai2.helpers import IteratorHelper
-from bai2.parsers import TransactionDetailParser, AccountParser, \
-    GroupParser, Bai2FileParser
-from bai2.constants import TypeCodes, FundsType, GroupStatus, \
-    AsOfDateModifier
-from bai2.models import \
-    Bai2File, Bai2FileHeader, Bai2FileTrailer, \
-    Group, GroupHeader, GroupTrailer, \
-    Account, AccountIdentifier, AccountTrailer, \
-    TransactionDetail
-from bai2.exceptions import ParsingException, \
-    NotSupportedYetException, IntegrityException
+from bai2.models import (
+    Account,
+    AccountIdentifier,
+    AccountTrailer,
+    Bai2File,
+    Bai2FileHeader,
+    Bai2FileTrailer,
+    Group,
+    GroupHeader,
+    GroupTrailer,
+    TransactionDetail,
+)
+from bai2.parsers import AccountParser, Bai2FileParser, GroupParser, TransactionDetailParser
 
 
 class TransactionDetailParserTestCase(TestCase):
@@ -34,14 +46,14 @@ class TransactionDetailParserTestCase(TestCase):
         self.assertEqual(transaction.customer_reference, None)
         self.assertEqual(
             transaction.text,
-            'DEALER PAYMENTS'
+            'DEALER PAYMENTS',
         )
 
     def test_continuation_record(self):
         lines = [
             '16,115,10000000,S,5000000,4000000,1000000/',
             '88,AX13612,B096132,AMALGAMATED CORP. LOCKBOX',
-            '88,DEPOSIT-MISC. RECEIVABLES'
+            '88,DEPOSIT-MISC. RECEIVABLES',
         ]
 
         parser = TransactionDetailParser(IteratorHelper(lines))
@@ -53,13 +65,13 @@ class TransactionDetailParserTestCase(TestCase):
         self.assertEqual(transaction.funds_type, FundsType.distributed_availability_simple)
         self.assertEqual(
             transaction.availability,
-            OrderedDict([('0', 5000000), ('1', 4000000), ('>1', 1000000)])
+            OrderedDict([('0', 5000000), ('1', 4000000), ('>1', 1000000)]),
         )
         self.assertEqual(transaction.bank_reference, 'AX13612')
         self.assertEqual(transaction.customer_reference, 'B096132')
         self.assertEqual(
             transaction.text,
-            'AMALGAMATED CORP. LOCKBOX DEPOSIT-MISC. RECEIVABLES'
+            'AMALGAMATED CORP. LOCKBOX DEPOSIT-MISC. RECEIVABLES',
         )
 
     def test_unknown_availability(self):
@@ -80,7 +92,7 @@ class TransactionDetailParserTestCase(TestCase):
         self.assertEqual(transaction.customer_reference, None)
         self.assertEqual(
             transaction.text,
-            'DEALER PAYMENTS'
+            'DEALER PAYMENTS',
         )
 
     def test_value_dated_availability(self):
@@ -102,11 +114,11 @@ class TransactionDetailParserTestCase(TestCase):
         self.assertEqual(transaction.funds_type, FundsType.value_dated)
         self.assertEqual(
             transaction.availability['date'],
-            datetime.date(day=15, month=7, year=2015)
+            datetime.date(day=15, month=7, year=2015),
         )
         self.assertEqual(
             transaction.availability['time'],
-            datetime.time(hour=23, minute=40)
+            datetime.time(hour=23, minute=40),
         )
 
     def test_distributed_availability_simple(self):
@@ -129,7 +141,7 @@ class TransactionDetailParserTestCase(TestCase):
         self.assertEqual(transaction.amount, 5)
         self.assertEqual(
             transaction.availability,
-            OrderedDict([('0', 1), ('1', 3), ('>1', 1)])
+            OrderedDict([('0', 1), ('1', 3), ('>1', 1)]),
         )
 
     def test_distributed_availability(self):
@@ -153,17 +165,75 @@ class TransactionDetailParserTestCase(TestCase):
 
         self.assertEqual(
             transaction.availability,
-            OrderedDict([('1', 1), ('2', 4)])
+            OrderedDict([('1', 1), ('2', 4)]),
         )
 
+    def test_real_time_payment_credit(self):
+        lines = [
+            '16,158,4346722,,0,0/',
+            '88, ACC NUM:=12345;',
+            '88, SENDER BNK:=PNC; ',
+            '88, SENDER ID:=9876;',
+            '88, SENDER ACC NUM:=0123456789;',
+            '88, ORG ID:=null;',
+            '88, ORG:=Some ARCHITECT Company ;',
+            '88, ORG ADDRESS:=AUSTIN TX US 78731-4297 ;',
+            '88, ORIG FI ID:=00000096; ',
+            '88, ORG FI ADDRESS:=null;',
+            '88, BNF ID:=9999988;',
+            '88, BNF NAME:=Some LLC; ',
+            '88, BNF ADDRESS:= Boston MA US 02116 ;',
+            '88, REC FI:=SVB;',
+            '88, REC ID:=121140399;',
+            '88, OBI:=PO 123 Inv #789',
+        ]
+
+        parser = TransactionDetailParser(IteratorHelper(lines))
+        transaction = parser.parse()
+        self.assertEqual(transaction.type_code.code, '158')
+        self.assertEqual(transaction.amount, 4346722)
+        self.assertEqual(len(transaction.rows), 16)
+
+    def test_unsupported_type_code_should_raise_unsupported_exception(self):
+        lines = [
+            '16,299,1500000,1,DD1620,,DEALER PAYMENTS',
+        ]
+
+        parser = TransactionDetailParser(IteratorHelper(lines))
+        self.assertRaises(NotSupportedYetException, parser.parse)
+
+    def test_custom_type_code(self):
+        """
+        Simulate adding a custom type code:
+
+        ```python
+        TypeCodes['299'] = TypeCode('299', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Custom transaction')
+        ```
+        """
+
+        lines = [
+            '16,299,1500000,1,DD1620,,DEALER PAYMENTS',
+        ]
+
+        with mock.patch.dict(TypeCodes, [
+            ('299', TypeCode('299', TypeCodeTransaction.credit, TypeCodeLevel.detail, 'Custom transaction')),
+        ]):
+            parser = TransactionDetailParser(IteratorHelper(lines))
+            transaction = parser.parse()
+
+        self.assertEqual(transaction.type_code.code, '299')
+        self.assertEqual(transaction.amount, 1500000)
+        self.assertEqual(transaction.bank_reference, 'DD1620')
+        self.assertEqual(transaction.customer_reference, None)
+        self.assertEqual(transaction.text, 'DEALER PAYMENTS')
+
 
 class AccountParserTestCase(TestCase):
-
     def test_parse(self):
         lines = [
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
-            '49,72000000,3/'
+            '49,72000000,3/',
         ]
 
         parser = AccountParser(IteratorHelper(lines))
@@ -183,7 +253,7 @@ class AccountParserTestCase(TestCase):
     def test_parse_without_transactions(self):
         lines = [
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
-            '49,70500000,2/'
+            '49,70500000,2/',
         ]
 
         parser = AccountParser(IteratorHelper(lines))
@@ -199,7 +269,7 @@ class AccountParserTestCase(TestCase):
             '16,115,10000000,S,5000000,4000000,1000000/',
             '88,AX13612,B096132,AMALGAMATED CORP. LOCKBOX',
             '88,DEPOSIT-MISC. RECEIVABLES',
-            '49,82000000,6/'
+            '49,82000000,6/',
         ]
 
         parser = AccountParser(IteratorHelper(lines))
@@ -223,7 +293,7 @@ class AccountParserTestCase(TestCase):
         lines = [
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
-            '49,72000000,4/'
+            '49,72000000,4/',
         ]
 
         parser = AccountParser(IteratorHelper(lines))
@@ -236,7 +306,7 @@ class AccountParserTestCase(TestCase):
         lines = [
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
-            '49,72000001,3/'
+            '49,72000001,3/',
         ]
 
         parser = AccountParser(IteratorHelper(lines))
@@ -250,7 +320,7 @@ class AccountParserTestCase(TestCase):
         lines = [
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
-            '49,72000001,3/'
+            '49,72000001,3/',
         ]
 
         parser = AccountParser(IteratorHelper(lines), check_integrity=False)
@@ -259,14 +329,13 @@ class AccountParserTestCase(TestCase):
 
 
 class GroupParserTestCase(TestCase):
-
     def test_parse(self):
         lines = [
             '02,031001234,122099999,1,040620,2359,GBP,2/',
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
-            '98,72000000,1,5/'
+            '98,72000000,1,5/',
         ]
 
         parser = GroupParser(IteratorHelper(lines))
@@ -299,7 +368,7 @@ class GroupParserTestCase(TestCase):
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
-            '98,72000000,1,5/'
+            '98,72000000,1,5/',
         ]
 
         parser = GroupParser(IteratorHelper(lines))
@@ -317,7 +386,7 @@ class GroupParserTestCase(TestCase):
             '49,72000000,3/',
             '03,0975312469,GBP,010,100,,/',
             '49,100,2/',
-            '98,72000100,2,7/'
+            '98,72000100,2,7/',
         ]
 
         parser = GroupParser(IteratorHelper(lines))
@@ -334,7 +403,7 @@ class GroupParserTestCase(TestCase):
     def test_fails_if_no_accounts_found(self):
         lines = [
             '02,031001234,122099999,1,040620,2359,,2/',
-            '98,11800000,0,2/'
+            '98,11800000,0,2/',
         ]
 
         parser = GroupParser(IteratorHelper(lines))
@@ -357,7 +426,7 @@ class GroupParserTestCase(TestCase):
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
-            '98,72000000,1,6/'
+            '98,72000000,1,6/',
         ]
 
         parser = GroupParser(IteratorHelper(lines))
@@ -372,7 +441,7 @@ class GroupParserTestCase(TestCase):
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,4/',
-            '98,72000000,1,5/'
+            '98,72000000,1,5/',
         ]
 
         parser = GroupParser(IteratorHelper(lines))
@@ -387,7 +456,7 @@ class GroupParserTestCase(TestCase):
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
-            '98,72000001,1,5/'
+            '98,72000001,1,5/',
         ]
 
         parser = GroupParser(IteratorHelper(lines))
@@ -403,7 +472,7 @@ class GroupParserTestCase(TestCase):
             '03,0975312468,GBP,010,500000,,,190,70000000,4,0/',
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
-            '98,72000001,2,6/'
+            '98,72000001,2,6/',
         ]
 
         parser = GroupParser(IteratorHelper(lines), check_integrity=False)
@@ -412,7 +481,6 @@ class GroupParserTestCase(TestCase):
 
 
 class Bai2FileParserTestCase(TestCase):
-
     def test_parse(self):
         lines = [
             '01,CITIDIRECT,8888888,150716,0713,00131100,,,2/',
@@ -428,7 +496,7 @@ class Bai2FileParserTestCase(TestCase):
             '88,BO:11111111 BO1:DOE JO',
             '49,20001,10/',
             '98,20001,1,12/',
-            '99,20001,1,14/'
+            '99,20001,1,14/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines))
@@ -475,9 +543,7 @@ class Bai2FileParserTestCase(TestCase):
         self.assertEqual(group_header.as_of_date, july_15_2015)
         self.assertEqual(group_header.as_of_time, datetime.time(hour=23, minute=40))
         self.assertEqual(group_header.currency, 'GBP')
-        self.assertEqual(
-            group_header.as_of_date_modifier, AsOfDateModifier.final_previous_day
-        )
+        self.assertEqual(group_header.as_of_date_modifier, AsOfDateModifier.final_previous_day)
 
         # Group Trailer
 
@@ -527,7 +593,7 @@ class Bai2FileParserTestCase(TestCase):
             'PY:RP1231231231231200                 A1234BC 22/03/66 '
             'BI:22222222 '
             'OB:111111 BUCKINGHAM PALACE OB3:BARCLAYS BANK PLC '
-            'BO:11111111 BO1:DOE JO'
+            'BO:11111111 BO1:DOE JO',
         )
 
     def test_only_version_2_supported(self):
@@ -541,7 +607,7 @@ class Bai2FileParserTestCase(TestCase):
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,18650000,3/',
             '98,18650000,1,5/',
-            '99,18650000,1,7/'
+            '99,18650000,1,7/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines))
@@ -560,7 +626,7 @@ class Bai2FileParserTestCase(TestCase):
             '03,0975312469,GBP,010,100,,/',
             '49,100,2/',
             '98,100,1,4/',
-            '99,72000100,2,11/'
+            '99,72000100,2,11/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines))
@@ -576,7 +642,7 @@ class Bai2FileParserTestCase(TestCase):
     def test_fails_if_no_groups_found(self):
         lines = [
             '01,122099999,123456789,040621,0200,1,,,2/',
-            '99,1215450000,0,2/'
+            '99,1215450000,0,2/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines))
@@ -601,7 +667,7 @@ class Bai2FileParserTestCase(TestCase):
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
             '98,72000000,1,5/',
-            '99,72000000,1,8/'
+            '99,72000000,1,8/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines))
@@ -618,7 +684,7 @@ class Bai2FileParserTestCase(TestCase):
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
             '98,72000000,1,5/',
-            '99,72000000,2,7/'
+            '99,72000000,2,7/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines))
@@ -635,7 +701,7 @@ class Bai2FileParserTestCase(TestCase):
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
             '98,72000000,1,5/',
-            '99,72000001,1,7/'
+            '99,72000001,1,7/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines))
@@ -653,7 +719,7 @@ class Bai2FileParserTestCase(TestCase):
             '16,165,1500000,1,DD1620,, DEALER PAYMENTS',
             '49,72000000,3/',
             '98,72000000,1,5/',
-            '99,72000001,2,8/'
+            '99,72000001,2,8/',
         ]
 
         parser = Bai2FileParser(IteratorHelper(lines), check_integrity=False)
